import { IRole } from 'aws-cdk-lib/aws-iam';
import * as kms from 'aws-cdk-lib/aws-kms';
import * as lf from 'aws-cdk-lib/aws-lakeformation';
import * as s3 from 'aws-cdk-lib/aws-s3';
import { Bucket } from 'aws-cdk-lib/aws-s3';
import * as sns from 'aws-cdk-lib/aws-sns';
import { Construct } from 'constructs';
import { LakeType } from '..';
import { Stage } from '../data-lake';
import { DataProduct } from '../data-product';
import { Pipeline, S3NotificationProperties } from '../pipeline';
export declare enum DataTier {
    RAW = "raw",
    REFINED = "refined",
    TRUSTED = "trusted"
}
export interface DataSetProperties {
    readonly encryptionKey?: kms.Key;
    readonly logBucket: s3.Bucket;
    readonly stage: Stage;
    readonly pipeline: Pipeline;
    readonly dataProduct: DataProduct;
    readonly s3BucketProps: s3.BucketProps | undefined;
    readonly lakeType: LakeType;
    readonly dataTiers: DataTier[];
    readonly datalakeAdminRole: IRole;
    readonly datalakeDbCreatorRole: IRole;
}
export interface DataSetResult {
    readonly destinationBucketName?: string;
    readonly destinationPrefix: string;
    readonly sourceBucketName: string | undefined;
    readonly sourceKeys: string[] | undefined;
}
export interface DataTierBucketProps {
    readonly lakeType: LakeType;
    readonly pipelineName: string;
    readonly bucketName: string | undefined;
    readonly dataCatalogAccountId: string;
    readonly logBucket: Bucket;
    readonly crossAccount: boolean;
    readonly s3BucketProps: s3.BucketProps | undefined;
    readonly s3NotificationProps: S3NotificationProperties | undefined;
    readonly datalakeAdminRole: IRole;
    readonly datalakeDbCreatorRole: IRole;
    readonly tier: DataTier;
}
export declare class DataSet extends Construct {
    readonly name: string;
    readonly lakeType: LakeType;
    readonly dropLocation?: DataTier;
    readonly rawBucketName?: string;
    readonly trustedBucketName?: string;
    readonly refinedBucketName?: string;
    readonly encryptionKey?: kms.Key;
    readonly downloadLocations?: DataSetResult;
    s3NotificationTopic?: sns.Topic;
    readonly pipeline: Pipeline;
    readonly dataProduct: DataProduct;
    locationRegistry: lf.CfnResource[];
    constructor(scope: Construct, id: string, props: DataSetProperties);
    private createS3NotificationTopic;
    private createDataTierBucket;
    private registerDataLakeLocation;
    private createDataLocationAccessPermission;
    getDataSetBucketName(dataTier: DataTier): string | undefined;
}
